#ifndef LIB_ERRDESC_MQH_INCLUDED
#define LIB_ERRDESC_MQH_INCLUDED
/**********************************************************************************
 * Copyright (C) 2010-2022 Dominik Egert <info@freie-netze.de>
 *
 * This file is error code error messages include file.
 *
 * MQLplus, including this file may not be copied and/or distributed 
 * without explecit permit by the author.
 * Author Dominik Egert / Freie Netze UG.
 **********************************************************************************
 *
 *  Version: 4.2
 *  State: public
 *
 *  File information
 *  ================
 *
 *  Use: resolve error codes to text.
 *
 *      Content is provided as is. All text
 *      and definitions have been extracted from
 *      https://docs.mql4.com/constants/errorswarnings/errorcodes
 *		
 *
 *      Feel free to edit or add any new codes
 *
 * 	Date of update: 29. April 2022
*/


// Language specific error code resolver (english)
const string LIB_ERROR_LANGUAGE_FUNCTION(LIB_ERROR_LANG_TERM_ID_EN)(const int error_code)
{
    // Perform switch error code
    switch(error_code)
    {
        // General

			/*0		*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_ERROR,										"ERR_NO_ERROR",									"No error returned.")
			/*1		*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_RESULT,									"ERR_NO_RESULT",								"No error returned, but the result is unknown.")
			/*2		*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_COMMON_ERROR,									"ERR_COMMON_ERROR",								"Common error.")
			/*3		*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_TRADE_PARAMETERS,						"ERR_INVALID_TRADE_PARAMETERS",					"Invalid trade parameters.")
			/*4		*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SERVER_BUSY,									"ERR_SERVER_BUSY",								"Trade server is busy.")
			/*5		*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OLD_VERSION,									"ERR_OLD_VERSION",								"Old version of the client terminal.")
			/*6		*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_CONNECTION,								"ERR_NO_CONNECTION",							"No connection with trade server.")
			/*7		*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_ENOUGH_RIGHTS,							"ERR_NOT_ENOUGH_RIGHTS",						"Not enough rights.")
			/*8		*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_FREQUENT_REQUESTS,						"ERR_TOO_FREQUENT_REQUESTS",					"Too frequent requests.")
			/*9		*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MALFUNCTIONAL_TRADE,							"ERR_MALFUNCTIONAL_TRADE",						"Malfunctional trade operation.")
			/*64	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ACCOUNT_DISABLED,								"ERR_ACCOUNT_DISABLED",							"Account disabled.")
			/*65	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_ACCOUNT,								"ERR_INVALID_ACCOUNT",							"Invalid account.")
			/*128	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_TIMEOUT,								"ERR_TRADE_TIMEOUT",							"Trade timeout.")
			/*129	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_PRICE,								"ERR_INVALID_PRICE",							"Invalid price.")
			/*130	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_STOPS,								"ERR_INVALID_STOPS",							"Invalid stops.")
			/*131	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_TRADE_VOLUME,							"ERR_INVALID_TRADE_VOLUME",						"Invalid trade volume.")
			/*132	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_CLOSED,								"ERR_MARKET_CLOSED",							"Market is closed.")
			/*133	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_DISABLED,								"ERR_TRADE_DISABLED",							"Trade is disabled.")
			/*134	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_ENOUGH_MONEY,								"ERR_NOT_ENOUGH_MONEY",							"Not enough money.")
			/*135	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_PRICE_CHANGED,								"ERR_PRICE_CHANGED",							"Price changed.")
			/*136	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OFF_QUOTES,									"ERR_OFF_QUOTES",								"Off quotes.")
			/*137	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BROKER_BUSY,									"ERR_BROKER_BUSY",								"Broker is busy.")
			/*138	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_REQUOTE,										"ERR_REQUOTE",									"Requote.")
			/*139	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ORDER_LOCKED,									"ERR_ORDER_LOCKED",								"Order is locked.")
			/*140	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_LONG_POSITIONS_ONLY_ALLOWED,					"ERR_LONG_POSITIONS_ONLY_ALLOWED",				"Long positions only allowed.")
			/*141	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_REQUESTS,							"ERR_TOO_MANY_REQUESTS",						"Too many requests.")
			/*145	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_MODIFY_DENIED,							"ERR_TRADE_MODIFY_DENIED",						"Modification denied because an order is too close to market.")
			/*146	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_CONTEXT_BUSY,							"ERR_TRADE_CONTEXT_BUSY",						"Trade context is busy.")
			/*147	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_EXPIRATION_DENIED,						"ERR_TRADE_EXPIRATION_DENIED",					"Expirations are denied by broker.")
			/*148	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_TOO_MANY_ORDERS,						"ERR_TRADE_TOO_MANY_ORDERS",					"The amount of opened and pending orders has reached the limit set by a broker.")
			/*149	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_HEDGE_PROHIBITED,						"ERR_TRADE_HEDGE_PROHIBITED",					"An attempt to open an order opposite to the existing one when hedging is disabled.")
			/*150	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_PROHIBITED_BY_FIFO,						"ERR_TRADE_PROHIBITED_BY_FIFO",					"An attempt to close an order contravening the FIFO rule.")


        // Return Codes of the Trade Server                                                         

			/*4000*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_MQLERROR,									"ERR_NO_MQLERROR",								"No error.")
			/*4001*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FUNCTION_POINTER,                     	"ERR_WRONG_FUNCTION_POINTER",                   "Wrong function pointer.")
			/*4002*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ARRAY_INDEX_OUT_OF_RANGE,                   	"ERR_ARRAY_INDEX_OUT_OF_RANGE",                 "Array index is out of range.")
			/*4003*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_MEMORY_FOR_FUNCTION_CALL_STACK,          	"ERR_NO_MEMORY_FOR_FUNCTION_CALL_STACK",        "No memory for function call stack.")
			/*4004*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RECURSIVE_STACK_OVERFLOW,                   	"ERR_RECURSIVE_STACK_OVERFLOW",                 "Recursive stack overflow.")
			/*4005*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_ENOUGH_STACK_FOR_PARAMETER,             	"ERR_NOT_ENOUGH_STACK_FOR_PARAMETER",           "Not enough stack for parameter.")
			/*4006*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_MEMORY_FOR_PARAMETER_STRING,             	"ERR_NO_MEMORY_FOR_PARAMETER_STRING",           "No memory for parameter string.")
			/*4007*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_MEMORY_FOR_TEMP_STRING,                  	"ERR_NO_MEMORY_FOR_TEMP_STRING",                "No memory for temp string.")
			/*4008*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_INITIALIZED_STRING,                     	"ERR_NOT_INITIALIZED_STRING",                   "Not initialized string.")
			/*4009*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_INITIALIZED_ARRAYSTRING,                	"ERR_NOT_INITIALIZED_ARRAYSTRING",              "Not initialized string in an array.")
			/*4010*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_MEMORY_FOR_ARRAYSTRING,                  	"ERR_NO_MEMORY_FOR_ARRAYSTRING",                "No memory for an array string.")
			/*4011*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_LONG_STRING,                            	"ERR_TOO_LONG_STRING",                          "Too long string.")
			/*4012*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_REMAINDER_FROM_ZERO_DIVIDE,                 	"ERR_REMAINDER_FROM_ZERO_DIVIDE",               "Remainder from zero divide.")
			/*4013*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ZERO_DIVIDE,                                	"ERR_ZERO_DIVIDE",                              "Zero divide.")
			/*4014*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_UNKNOWN_COMMAND,                            	"ERR_UNKNOWN_COMMAND",                          "Unknown command.")
			/*4015*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_JUMP,                                 	"ERR_WRONG_JUMP",                               "Wrong jump.")
			/*4016*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_INITIALIZED_ARRAY,                      	"ERR_NOT_INITIALIZED_ARRAY",                    "Not initialized array.")
			/*4017*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DLL_CALLS_NOT_ALLOWED,                      	"ERR_DLL_CALLS_NOT_ALLOWED",                    "DLL calls are not allowed.")
			/*4018*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_LOAD_LIBRARY,                        	"ERR_CANNOT_LOAD_LIBRARY",                      "Cannot load library.")
			/*4019*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_CALL_FUNCTION,                       	"ERR_CANNOT_CALL_FUNCTION",                     "Cannot call function.")
			/*4020*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_EXTERNAL_EXPERT_CALLS_NOT_ALLOWED,          	"ERR_EXTERNAL_EXPERT_CALLS_NOT_ALLOWED",        "EA function calls are not allowed.")
			/*4021*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_ENOUGH_MEMORY_FOR_RETURNED_STRING,      	"ERR_NOT_ENOUGH_MEMORY_FOR_RETURNED_STRING",    "Not enough memory for a string returned from a function.")
			/*4022*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SYSTEM_BUSY,                                	"ERR_SYSTEM_BUSY",                              "System is busy.")
			/*4050*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_FUNCTION_PARAMETERS_COUNT,          	"ERR_INVALID_FUNCTION_PARAMETERS_COUNT",        "Invalid function parameters count.")
			/*4051*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_FUNCTION_PARAMETER_VALUE,           	"ERR_INVALID_FUNCTION_PARAMETER_VALUE",         "Invalid function parameter value.")
			/*4052*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_FUNCTION_INTERNAL_ERROR,             	"ERR_STRING_FUNCTION_INTERNAL_ERROR",           "String function internal error.")
			/*4053*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SOME_ARRAY_ERROR,                           	"ERR_SOME_ARRAY_ERROR",                         "Some array error.")
			/*4054*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INCORRECT_SERIES_ARRAY_USING,               	"ERR_INCORRECT_SERIES_ARRAY_USING",             "Incorrect series array using.")
			/*4055*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_INDICATOR_ERROR,                     	"ERR_CUSTOM_INDICATOR_ERROR",                   "Custom indicator error.")
			/*4056*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INCOMPATIBLE_ARRAYS,                        	"ERR_INCOMPATIBLE_ARRAYS",                      "Arrays are incompatible.")
			/*4057*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBAL_VARIABLES_PROCESSING_ERROR,          	"ERR_GLOBAL_VARIABLES_PROCESSING_ERROR",        "Global variables processing error.")
			/*4058*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBAL_VARIABLE_NOT_FOUND,                  	"ERR_GLOBAL_VARIABLE_NOT_FOUND",                "Global variable not found.")
			/*4059*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FUNCTION_NOT_ALLOWED_IN_TESTING_MODE,       	"ERR_FUNCTION_NOT_ALLOWED_IN_TESTING_MODE",     "Function is not allowed in testing mode.")
			/*4060*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FUNCTION_NOT_CONFIRMED,                     	"ERR_FUNCTION_NOT_CONFIRMED",                   "Function is not confirmed.")
			/*4061*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SEND_MAIL_ERROR,                            	"ERR_SEND_MAIL_ERROR",                          "Mail sending error.")
			/*4062*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_PARAMETER_EXPECTED,                  	"ERR_STRING_PARAMETER_EXPECTED",                "String parameter expected.")
			/*4063*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INTEGER_PARAMETER_EXPECTED,                 	"ERR_INTEGER_PARAMETER_EXPECTED",               "Integer parameter expected.")
			/*4064*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DOUBLE_PARAMETER_EXPECTED,                  	"ERR_DOUBLE_PARAMETER_EXPECTED",                "Double parameter expected.")
			/*4065*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ARRAY_AS_PARAMETER_EXPECTED,                	"ERR_ARRAY_AS_PARAMETER_EXPECTED",              "Array as parameter expected.")
			/*4066*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_WILL_UPDATED,                       	"ERR_HISTORY_WILL_UPDATED",                     "Requested history data in updating state.")
			/*4067*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_ERROR,                                	"ERR_TRADE_ERROR",                              "Some error in trade operation execution.")
			/*4099*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_END_OF_FILE,                                	"ERR_END_OF_FILE",                              "End of a file.")
			/*4100*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SOME_FILE_ERROR,                            	"ERR_SOME_FILE_ERROR",                          "Some file error.")
			/*4101*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FILE_NAME,                            	"ERR_WRONG_FILE_NAME",                          "Wrong file name.")
			/*4102*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_OPENED_FILES,                      	"ERR_TOO_MANY_OPENED_FILES",                    "Too many opened files.")
			/*4103*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_OPEN_FILE,                           	"ERR_CANNOT_OPEN_FILE",                         "Cannot open file.")
			/*4104*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INCOMPATIBLE_ACCESS_TO_FILE,                	"ERR_INCOMPATIBLE_ACCESS_TO_FILE",              "Incompatible access to a file.")
			/*4105*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_ORDER_SELECTED,                          	"ERR_NO_ORDER_SELECTED",                        "No order selected.")
			/*4106*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_UNKNOWN_SYMBOL,                             	"ERR_UNKNOWN_SYMBOL",                           "Unknown symbol.")
			/*4107*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_PRICE_PARAM,                        	"ERR_INVALID_PRICE_PARAM",                      "Invalid price.")
			/*4108*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_TICKET,                             	"ERR_INVALID_TICKET",                           "Invalid ticket.")
			/*4109*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_NOT_ALLOWED,                          	"ERR_TRADE_NOT_ALLOWED",                        "Trade is not allowed.")
			/*4110*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_LONGS_NOT_ALLOWED,                          	"ERR_LONGS_NOT_ALLOWED",                        "Longs are not allowed.")
			/*4111*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SHORTS_NOT_ALLOWED,                         	"ERR_SHORTS_NOT_ALLOWED",                       "Shorts are not allowed.")
			/*4200*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_ALREADY_EXISTS,                      	"ERR_OBJECT_ALREADY_EXISTS",                    "Object already exists.")
			/*4201*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_UNKNOWN_OBJECT_PROPERTY,                    	"ERR_UNKNOWN_OBJECT_PROPERTY",                  "Unknown object property.")
			/*4202*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_DOES_NOT_EXIST,                      	"ERR_OBJECT_DOES_NOT_EXIST",                    "Object does not exist.")
			/*4203*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_UNKNOWN_OBJECT_TYPE,                        	"ERR_UNKNOWN_OBJECT_TYPE",                      "Unknown object type.")
			/*4204*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_OBJECT_NAME,                             	"ERR_NO_OBJECT_NAME",                           "No object name.")
			/*4205*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_COORDINATES_ERROR,                   	"ERR_OBJECT_COORDINATES_ERROR",                 "Object coordinates error.")
			/*4206*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_SPECIFIED_SUBWINDOW,                     	"ERR_NO_SPECIFIED_SUBWINDOW",                   "No specified subwindow.")
			/*4207*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SOME_OBJECT_ERROR,                          	"ERR_SOME_OBJECT_ERROR",                        "Some error in object operation.")
			/*4210*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_PROP_INVALID,							"ERR_CHART_PROP_INVALID",						"Unknown chart property")
			/*4211*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NOT_FOUND,                              "ERR_CHART_NOT_FOUND",                          "Chart not found")
			/*4212*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHARTWINDOW_NOT_FOUND,                        "ERR_CHARTWINDOW_NOT_FOUND",                    "Chart subwindow not found")
			/*4213*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHARTINDICATOR_NOT_FOUND,                     "ERR_CHARTINDICATOR_NOT_FOUND",                 "Chart indicator not found")
			/*4220*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SYMBOL_SELECT,                                "ERR_SYMBOL_SELECT",                            "Symbol select error")
			/*4250*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_ERROR,                           "ERR_NOTIFICATION_ERROR",                       "Notification error")
			/*4251*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_PARAMETER,                       "ERR_NOTIFICATION_PARAMETER",                   "Notification parameter error")
			/*4252*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_SETTINGS,                        "ERR_NOTIFICATION_SETTINGS",                    "Notifications disabled")
			/*4253*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_TOO_FREQUENT,                    "ERR_NOTIFICATION_TOO_FREQUENT",                "Notification send too frequent")
			/*4260*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_NOSERVER,                                 "ERR_FTP_NOSERVER",                             "FTP server is not specified")
			/*4261*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_NOLOGIN,                                  "ERR_FTP_NOLOGIN",                              "FTP login is not specified")
			/*4262*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CONNECT_FAILED,                           "ERR_FTP_CONNECT_FAILED",                       "FTP connection failed")
			/*4263*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CLOSED,                                   "ERR_FTP_CLOSED",                               "FTP connection closed")
			/*4264*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CHANGEDIR,                                "ERR_FTP_CHANGEDIR",                            "FTP path not found on server")
			/*4265*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_FILE_ERROR,                               "ERR_FTP_FILE_ERROR",                           "File not found in the MQL4/Files directory to send on FTP server")
			/*4266*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_ERROR,                                    "ERR_FTP_ERROR",                                "Common error during FTP data transmission")
			/*5001*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_TOO_MANY_OPENED,                         "ERR_FILE_TOO_MANY_OPENED",                     "Too many opened files")
			/*5002*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_WRONG_FILENAME,                          "ERR_FILE_WRONG_FILENAME",                      "Wrong file name")
			/*5003*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_TOO_LONG_FILENAME,                       "ERR_FILE_TOO_LONG_FILENAME",                   "Too long file name")
			/*5004*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_CANNOT_OPEN,                             "ERR_FILE_CANNOT_OPEN",                         "Cannot open file")
			/*5005*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_BUFFER_ALLOCATION_ERROR,                 "ERR_FILE_BUFFER_ALLOCATION_ERROR",             "Text file buffer allocation error")
			/*5006*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_CANNOT_DELETE,                           "ERR_FILE_CANNOT_DELETE",                       "Cannot delete file")
			/*5007*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_INVALID_HANDLE,                          "ERR_FILE_INVALID_HANDLE",                      "Invalid file handle (file closed or was not opened)")
			/*5008*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_WRONG_HANDLE,                            "ERR_FILE_WRONG_HANDLE",                        "Wrong file handle (handle index is out of handle table)")
			/*5009*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOT_TOWRITE,                             "ERR_FILE_NOT_TOWRITE",                         "File must be opened with FILE_WRITE flag")
			/*5010*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOT_TOREAD,                              "ERR_FILE_NOT_TOREAD",                          "File must be opened with FILE_READ flag")
			/*5011*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOT_BIN,                                 "ERR_FILE_NOT_BIN",                             "File must be opened with FILE_BIN flag")
			/*5012*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOT_TXT,                                 "ERR_FILE_NOT_TXT",                             "File must be opened with FILE_TXT flag")
			/*5013*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOT_TXTORCSV,                            "ERR_FILE_NOT_TXTORCSV",                        "File must be opened with FILE_TXT or FILE_CSV flag")
			/*5014*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOT_CSV,                                 "ERR_FILE_NOT_CSV",                             "File must be opened with FILE_CSV flag")
			/*5015*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_READ_ERROR,                              "ERR_FILE_READ_ERROR",                          "File read error")
			/*5016*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_WRITE_ERROR,                             "ERR_FILE_WRITE_ERROR",                         "File write error")
			/*5017*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_BIN_STRINGSIZE,                          "ERR_FILE_BIN_STRINGSIZE",                      "String size must be specified for binary file")
			/*5018*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_INCOMPATIBLE,                            "ERR_FILE_INCOMPATIBLE",                        "Incompatible file (for string arrays-TXT, for others-BIN)")
			/*5019*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_IS_DIRECTORY,                            "ERR_FILE_IS_DIRECTORY",                        "File is directory not file")
			/*5020*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOT_EXIST,                               "ERR_FILE_NOT_EXIST",                           "File does not exist")
			/*5021*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_CANNOT_REWRITE,                          "ERR_FILE_CANNOT_REWRITE",                      "File cannot be rewritten")
			/*5022*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_WRONG_DIRECTORYNAME,                     "ERR_FILE_WRONG_DIRECTORYNAME",                 "Wrong directory name")
			/*5023*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_DIRECTORY_NOT_EXIST,                     "ERR_FILE_DIRECTORY_NOT_EXIST",                 "Directory does not exist")
			/*5024*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOT_DIRECTORY,                           "ERR_FILE_NOT_DIRECTORY",                       "Specified file is not directory")
			/*5025*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_CANNOT_DELETE_DIRECTORY,                 "ERR_FILE_CANNOT_DELETE_DIRECTORY",             "Cannot delete directory")
			/*5026*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_CANNOT_CLEAN_DIRECTORY,                  "ERR_FILE_CANNOT_CLEAN_DIRECTORY",              "Cannot clean directory")
			/*5027*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_ARRAYRESIZE_ERROR,                       "ERR_FILE_ARRAYRESIZE_ERROR",                   "Array resize error")
			/*5028*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_STRINGRESIZE_ERROR,                      "ERR_FILE_STRINGRESIZE_ERROR",                  "String resize error")
			/*5029*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_STRUCT_WITH_OBJECTS,                     "ERR_FILE_STRUCT_WITH_OBJECTS",                 "Structure contains strings or dynamic arrays")
			/*5200*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_INVALID_ADDRESS,                   "ERR_WEBREQUEST_INVALID_ADDRESS",               "Invalid URL")
			/*5201*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_CONNECT_FAILED,                    "ERR_WEBREQUEST_CONNECT_FAILED",                "Failed to connect to specified URL")
			/*5202*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_TIMEOUT,                           "ERR_WEBREQUEST_TIMEOUT",                       "Timeout exceeded")
			/*5203*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_REQUEST_FAILED,                    "ERR_WEBREQUEST_REQUEST_FAILED",                "HTTP request failed")
    }

    // Return
    return(NULL);
}


// Language specific error code resolver (russian)
const string LIB_ERROR_LANGUAGE_FUNCTION(LIB_ERROR_LANG_TERM_ID_RU)(const int error_code)
{
    // Perform switch error code
    switch(error_code)
    {
        // General

			/*0		*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_ERROR,										"ERR_NO_ERROR",									"Нет ошибки.")
			/*1		*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_RESULT,									"ERR_NO_RESULT",								"Нет ошибки, но результат неизвестен.")
			/*2		*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_COMMON_ERROR,									"ERR_COMMON_ERROR",								"Общая ошибка.")
			/*3		*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_TRADE_PARAMETERS,						"ERR_INVALID_TRADE_PARAMETERS",					"Неправильные параметры.")
			/*4		*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SERVER_BUSY,									"ERR_SERVER_BUSY",								"Торговый сервер занят.")
			/*5		*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OLD_VERSION,									"ERR_OLD_VERSION",								"Старая версия клиентского терминала.")
			/*6		*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_CONNECTION,								"ERR_NO_CONNECTION",							"Нет связи с торговым сервером.")
			/*7		*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_ENOUGH_RIGHTS,							"ERR_NOT_ENOUGH_RIGHTS",						"Недостаточно прав.")
			/*8		*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_FREQUENT_REQUESTS,						"ERR_TOO_FREQUENT_REQUESTS",					"Слишком частые запросы.")
			/*9		*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MALFUNCTIONAL_TRADE,							"ERR_MALFUNCTIONAL_TRADE",						"Недопустимая операция нарушающая функционирование сервера.")
			/*64	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ACCOUNT_DISABLED,								"ERR_ACCOUNT_DISABLED",							"Счет заблокирован.")
			/*65	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_ACCOUNT,								"ERR_INVALID_ACCOUNT",							"Неправильный номер счета.")
			/*128	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_TIMEOUT,								"ERR_TRADE_TIMEOUT",							"Истек срок ожидания совершения сделки.")
			/*129	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_PRICE,								"ERR_INVALID_PRICE",							"Неправильная цена.")
			/*130	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_STOPS,								"ERR_INVALID_STOPS",							"Неправильные стопы.")
			/*131	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_TRADE_VOLUME,							"ERR_INVALID_TRADE_VOLUME",						"Неправильный объем.")
			/*132	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_CLOSED,								"ERR_MARKET_CLOSED",							"Рынок закрыт.")
			/*133	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_DISABLED,								"ERR_TRADE_DISABLED",							"Торговля запрещена.")
			/*134	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_ENOUGH_MONEY,								"ERR_NOT_ENOUGH_MONEY",							"Недостаточно денег для совершения операции.")
			/*135	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_PRICE_CHANGED,								"ERR_PRICE_CHANGED",							"Цена изменилась.")
			/*136	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OFF_QUOTES,									"ERR_OFF_QUOTES",								"Нет цен.")
			/*137	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BROKER_BUSY,									"ERR_BROKER_BUSY",								"Брокер занят.")
			/*138	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_REQUOTE,										"ERR_REQUOTE",									"Новые цены.")
			/*139	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ORDER_LOCKED,									"ERR_ORDER_LOCKED",								"Ордер заблокирован и уже обрабатывается.")
			/*140	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_LONG_POSITIONS_ONLY_ALLOWED,					"ERR_LONG_POSITIONS_ONLY_ALLOWED",				"Разрешена только покупка.")
			/*141	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_REQUESTS,							"ERR_TOO_MANY_REQUESTS",						"Слишком много запросов.")
			/*145	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_MODIFY_DENIED,							"ERR_TRADE_MODIFY_DENIED",						"Модификация запрещена, так как ордер слишком близок к рынку.")
			/*146	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_CONTEXT_BUSY,							"ERR_TRADE_CONTEXT_BUSY",						"Подсистема торговли занята.")
			/*147	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_EXPIRATION_DENIED,						"ERR_TRADE_EXPIRATION_DENIED",					"Использование даты истечения ордера запрещено брокером.")
			/*148	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_TOO_MANY_ORDERS,						"ERR_TRADE_TOO_MANY_ORDERS",					"Количество открытых и отложенных ордеров достигло предела, установленного брокером.")
			/*149	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_HEDGE_PROHIBITED,						"ERR_TRADE_HEDGE_PROHIBITED",					"Попытка открыть противоположный ордер в случае, если хеджирование запрещено.")
			/*150	*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_PROHIBITED_BY_FIFO,						"ERR_TRADE_PROHIBITED_BY_FIFO",					"Попытка закрыть позицию по инструменту в противоречии с правилом FIFO.")


        // Return Codes of the Trade Server                                                         

			/*4000*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_MQLERROR,									"ERR_NO_MQLERROR",								"Нет ошибки.")
			/*4001*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FUNCTION_POINTER,                     	"ERR_WRONG_FUNCTION_POINTER",                   "Неправильный указатель функции.")
			/*4002*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ARRAY_INDEX_OUT_OF_RANGE,                   	"ERR_ARRAY_INDEX_OUT_OF_RANGE",                 "Индекс массива - вне диапазона.")
			/*4003*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_MEMORY_FOR_FUNCTION_CALL_STACK,          	"ERR_NO_MEMORY_FOR_FUNCTION_CALL_STACK",        "Нет памяти для стека функций.")
			/*4004*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RECURSIVE_STACK_OVERFLOW,                   	"ERR_RECURSIVE_STACK_OVERFLOW",                 "Переполнение стека после рекурсивного вызова.")
			/*4005*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_ENOUGH_STACK_FOR_PARAMETER,             	"ERR_NOT_ENOUGH_STACK_FOR_PARAMETER",           "На стеке нет памяти для передачи параметров.")
			/*4006*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_MEMORY_FOR_PARAMETER_STRING,             	"ERR_NO_MEMORY_FOR_PARAMETER_STRING",           "Нет памяти для строкового параметра.")
			/*4007*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_MEMORY_FOR_TEMP_STRING,                  	"ERR_NO_MEMORY_FOR_TEMP_STRING",                "Нет памяти для временной строки.")
			/*4008*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_INITIALIZED_STRING,                     	"ERR_NOT_INITIALIZED_STRING",                   "Неинициализированная строка.")
			/*4009*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_INITIALIZED_ARRAYSTRING,                	"ERR_NOT_INITIALIZED_ARRAYSTRING",              "Неинициализированная строка в массиве.")
			/*4010*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_MEMORY_FOR_ARRAYSTRING,                  	"ERR_NO_MEMORY_FOR_ARRAYSTRING",                "Нет памяти для строкового массива.")
			/*4011*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_LONG_STRING,                            	"ERR_TOO_LONG_STRING",                          "Слишком длинная строка.")
			/*4012*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_REMAINDER_FROM_ZERO_DIVIDE,                 	"ERR_REMAINDER_FROM_ZERO_DIVIDE",               "Остаток от деления на ноль.")
			/*4013*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ZERO_DIVIDE,                                	"ERR_ZERO_DIVIDE",                              "Деление на ноль.")
			/*4014*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_UNKNOWN_COMMAND,                            	"ERR_UNKNOWN_COMMAND",                          "Неизвестная команда.")
			/*4015*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_JUMP,                                 	"ERR_WRONG_JUMP",                               "Неправильный переход.")
			/*4016*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_INITIALIZED_ARRAY,                      	"ERR_NOT_INITIALIZED_ARRAY",                    "Неинициализированный массив.")
			/*4017*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DLL_CALLS_NOT_ALLOWED,                      	"ERR_DLL_CALLS_NOT_ALLOWED",                    "Вызовы DLL не разрешены.")
			/*4018*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_LOAD_LIBRARY,                        	"ERR_CANNOT_LOAD_LIBRARY",                      "Невозможно загрузить библиотеку.")
			/*4019*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_CALL_FUNCTION,                       	"ERR_CANNOT_CALL_FUNCTION",                     "Невозможно вызвать функцию.")
			/*4020*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_EXTERNAL_EXPERT_CALLS_NOT_ALLOWED,          	"ERR_EXTERNAL_EXPERT_CALLS_NOT_ALLOWED",        "Вызовы внешних библиотечных функций не разрешены.")
			/*4021*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_ENOUGH_MEMORY_FOR_RETURNED_STRING,      	"ERR_NOT_ENOUGH_MEMORY_FOR_RETURNED_STRING",    "Недостаточно памяти для строки, возвращаемой из функции.")
			/*4022*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SYSTEM_BUSY,                                	"ERR_SYSTEM_BUSY",                              "Система занята.")
			/*4050*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_FUNCTION_PARAMETERS_COUNT,          	"ERR_INVALID_FUNCTION_PARAMETERS_COUNT",        "Неправильное количество параметров функции.")
			/*4051*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_FUNCTION_PARAMETER_VALUE,           	"ERR_INVALID_FUNCTION_PARAMETER_VALUE",         "Недопустимое значение параметра функции.")
			/*4052*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_FUNCTION_INTERNAL_ERROR,             	"ERR_STRING_FUNCTION_INTERNAL_ERROR",           "Внутренняя ошибка строковой функции.")
			/*4053*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SOME_ARRAY_ERROR,                           	"ERR_SOME_ARRAY_ERROR",                         "Ошибка массива.")
			/*4054*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INCORRECT_SERIES_ARRAY_USING,               	"ERR_INCORRECT_SERIES_ARRAY_USING",             "Неправильное использование массива-таймсерии.")
			/*4055*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_INDICATOR_ERROR,                     	"ERR_CUSTOM_INDICATOR_ERROR",                   "Ошибка пользовательского индикатора.")
			/*4056*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INCOMPATIBLE_ARRAYS,                        	"ERR_INCOMPATIBLE_ARRAYS",                      "Массивы несовместимы.")
			/*4057*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBAL_VARIABLES_PROCESSING_ERROR,          	"ERR_GLOBAL_VARIABLES_PROCESSING_ERROR",        "Ошибка обработки глобальныех переменных.")
			/*4058*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBAL_VARIABLE_NOT_FOUND,                  	"ERR_GLOBAL_VARIABLE_NOT_FOUND",                "Глобальная переменная не обнаружена.")
			/*4059*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FUNCTION_NOT_ALLOWED_IN_TESTING_MODE,       	"ERR_FUNCTION_NOT_ALLOWED_IN_TESTING_MODE",     "Функция не разрешена в тестовом режиме.")
			/*4060*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FUNCTION_NOT_CONFIRMED,                     	"ERR_FUNCTION_NOT_CONFIRMED",                   "Функция не подтверждена.")
			/*4061*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SEND_MAIL_ERROR,                            	"ERR_SEND_MAIL_ERROR",                          "Ошибка отправки почты.")
			/*4062*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_PARAMETER_EXPECTED,                  	"ERR_STRING_PARAMETER_EXPECTED",                "Ожидается параметр типа string.")
			/*4063*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INTEGER_PARAMETER_EXPECTED,                 	"ERR_INTEGER_PARAMETER_EXPECTED",               "Ожидается параметр типа integer.")
			/*4064*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DOUBLE_PARAMETER_EXPECTED,                  	"ERR_DOUBLE_PARAMETER_EXPECTED",                "Ожидается параметр типа double.")
			/*4065*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ARRAY_AS_PARAMETER_EXPECTED,                	"ERR_ARRAY_AS_PARAMETER_EXPECTED",              "В качестве параметра ожидается массив.")
			/*4066*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_WILL_UPDATED,                       	"ERR_HISTORY_WILL_UPDATED",                     "Запрошенные исторические данные в состоянии обновления.")
			/*4067*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_ERROR,                                	"ERR_TRADE_ERROR",                              "Ошибка при выполнении торговой операции.")
			/*4099*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_END_OF_FILE,                                	"ERR_END_OF_FILE",                              "Конец файла.")
			/*4100*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SOME_FILE_ERROR,                            	"ERR_SOME_FILE_ERROR",                          "Ошибка при работе с файлом.")
			/*4101*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FILE_NAME,                            	"ERR_WRONG_FILE_NAME",                          "Неправильное имя файла.")
			/*4102*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_OPENED_FILES,                      	"ERR_TOO_MANY_OPENED_FILES",                    "Слишком много открытых файлов.")
			/*4103*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_OPEN_FILE,                           	"ERR_CANNOT_OPEN_FILE",                         "Невозможно открыть файл.")
			/*4104*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INCOMPATIBLE_ACCESS_TO_FILE,                	"ERR_INCOMPATIBLE_ACCESS_TO_FILE",              "Несовместимый режим доступа к файлу.")
			/*4105*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_ORDER_SELECTED,                          	"ERR_NO_ORDER_SELECTED",                        "Ни один ордер не выбран.")
			/*4106*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_UNKNOWN_SYMBOL,                             	"ERR_UNKNOWN_SYMBOL",                           "Неизвестный символ.")
			/*4107*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_PRICE_PARAM,                        	"ERR_INVALID_PRICE_PARAM",                      "Неправильный параметр цены для торговой функции.")
			/*4108*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_TICKET,                             	"ERR_INVALID_TICKET",                           "Неверный номер тикета.")
			/*4109*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_NOT_ALLOWED,                          	"ERR_TRADE_NOT_ALLOWED",                        "Торговля не разрешена.")
			/*4110*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_LONGS_NOT_ALLOWED,                          	"ERR_LONGS_NOT_ALLOWED",                        "Длинные позиции не разрешены.")
			/*4111*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SHORTS_NOT_ALLOWED,                         	"ERR_SHORTS_NOT_ALLOWED",                       "Короткие позиции не разрешены.")
			/*4200*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_ALREADY_EXISTS,                      	"ERR_OBJECT_ALREADY_EXISTS",                    "Объект уже существует.")
			/*4201*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_UNKNOWN_OBJECT_PROPERTY,                    	"ERR_UNKNOWN_OBJECT_PROPERTY",                  "Запрошено неизвестное свойство объекта.")
			/*4202*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_DOES_NOT_EXIST,                      	"ERR_OBJECT_DOES_NOT_EXIST",                    "Объект не существует.")
			/*4203*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_UNKNOWN_OBJECT_TYPE,                        	"ERR_UNKNOWN_OBJECT_TYPE",                      "Неизвестный тип объекта.")
			/*4204*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_OBJECT_NAME,                             	"ERR_NO_OBJECT_NAME",                           "Нет имени объекта.")
			/*4205*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_COORDINATES_ERROR,                   	"ERR_OBJECT_COORDINATES_ERROR",                 "Ошибка координат объекта.")
			/*4206*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_SPECIFIED_SUBWINDOW,                     	"ERR_NO_SPECIFIED_SUBWINDOW",                   "Не найдено указанное подокно.")
			/*4207*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SOME_OBJECT_ERROR,                          	"ERR_SOME_OBJECT_ERROR",                        "Ошибка при работе с объектом.")
			/*4210*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_PROP_INVALID,							"ERR_CHART_PROP_INVALID",						"Неизвестное свойство графика.")
			/*4211*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NOT_FOUND,                              "ERR_CHART_NOT_FOUND",                          "График не найден.")
			/*4212*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHARTWINDOW_NOT_FOUND,                        "ERR_CHARTWINDOW_NOT_FOUND",                    "Не найдено подокно графика.")
			/*4213*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHARTINDICATOR_NOT_FOUND,                     "ERR_CHARTINDICATOR_NOT_FOUND",                 "Индикатор не найден.")
			/*4220*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SYMBOL_SELECT,                                "ERR_SYMBOL_SELECT",                            "Ошибка выбора инструмента.")
			/*4250*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_ERROR,                           "ERR_NOTIFICATION_ERROR",                       "Ошибка отправки push-уведомления.")
			/*4251*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_PARAMETER,                       "ERR_NOTIFICATION_PARAMETER",                   "Ошибка параметров push-уведомления.")
			/*4252*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_SETTINGS,                        "ERR_NOTIFICATION_SETTINGS",                    "Уведомления запрещены.")
			/*4253*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_TOO_FREQUENT,                    "ERR_NOTIFICATION_TOO_FREQUENT",                "Слишком частые запросы отсылки push-уведомлений.")
			/*4260*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_NOSERVER,                                 "ERR_FTP_NOSERVER",                             "Не указан FTP сервер.")
			/*4261*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_NOLOGIN,                                  "ERR_FTP_NOLOGIN",                              "Не указан FTP логин.")
			/*4262*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CONNECT_FAILED,                           "ERR_FTP_CONNECT_FAILED",                       "Ошибка при подключении к FTP серверу.")
			/*4263*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CLOSED,                                   "ERR_FTP_CLOSED",                               "Подключение к FTP серверу закрыто.")
			/*4264*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CHANGEDIR,                                "ERR_FTP_CHANGEDIR",                            "На FTP сервере не найдена директория для выгрузки файла.")
			/*4265*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_FILE_ERROR,                               "ERR_FTP_FILE_ERROR",                           "Не найден файл в директории MQL4/Files для отправки на FTP сервер.")
			/*4266*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_ERROR,                                    "ERR_FTP_ERROR",                                "Ошибка при передаче файла на FTP сервер.")
			/*5001*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_TOO_MANY_OPENED,                         "ERR_FILE_TOO_MANY_OPENED",                     "Слишком много открытых файлов.")
			/*5002*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_WRONG_FILENAME,                          "ERR_FILE_WRONG_FILENAME",                      "Неверное имя файла.")
			/*5003*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_TOO_LONG_FILENAME,                       "ERR_FILE_TOO_LONG_FILENAME",                   "Слишком длинное имя файла.")
			/*5004*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_CANNOT_OPEN,                             "ERR_FILE_CANNOT_OPEN",                         "Ошибка открытия файла.")
			/*5005*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_BUFFER_ALLOCATION_ERROR,                 "ERR_FILE_BUFFER_ALLOCATION_ERROR",             "Ошибка размещения буфера текстового файла.")
			/*5006*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_CANNOT_DELETE,                           "ERR_FILE_CANNOT_DELETE",                       "Ошибка удаления файла.")
			/*5007*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_INVALID_HANDLE,                          "ERR_FILE_INVALID_HANDLE",                      "Неверный хендл файла (файл закрыт или не был открыт).")
			/*5008*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_WRONG_HANDLE,                            "ERR_FILE_WRONG_HANDLE",                        "Неверный хендл файла (индекс хендла отсутствует в таблице).")
			/*5009*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOT_TOWRITE,                             "ERR_FILE_NOT_TOWRITE",                         "Файл должен быть открыт с флагом FILE_WRITE.")
			/*5010*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOT_TOREAD,                              "ERR_FILE_NOT_TOREAD",                          "Файл должен быть открыт с флагом FILE_READ.")
			/*5011*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOT_BIN,                                 "ERR_FILE_NOT_BIN",                             "Файл должен быть открыт с флагом FILE_BIN.")
			/*5012*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOT_TXT,                                 "ERR_FILE_NOT_TXT",                             "Файл должен быть открыт с флагом FILE_TXT.")
			/*5013*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOT_TXTORCSV,                            "ERR_FILE_NOT_TXTORCSV",                        "Файл должен быть открыт с флагом FILE_TXT или FILE_CSV.")
			/*5014*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOT_CSV,                                 "ERR_FILE_NOT_CSV",                             "Файл должен быть открыт с флагом FILE_CSV.")
			/*5015*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_READ_ERROR,                              "ERR_FILE_READ_ERROR",                          "Ошибка чтения файла.")
			/*5016*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_WRITE_ERROR,                             "ERR_FILE_WRITE_ERROR",                         "Ошибка записи файла.")
			/*5017*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_BIN_STRINGSIZE,                          "ERR_FILE_BIN_STRINGSIZE",                      "Размер строки должен быть указан для двоичных файлов.")
			/*5018*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_INCOMPATIBLE,                            "ERR_FILE_INCOMPATIBLE",                        "Неверный тип файла (для строковых массивов-TXT, для всех других-BIN).")
			/*5019*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_IS_DIRECTORY,                            "ERR_FILE_IS_DIRECTORY",                        "Файл является директорией.")
			/*5020*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOT_EXIST,                               "ERR_FILE_NOT_EXIST",                           "Файл не существует.")
			/*5021*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_CANNOT_REWRITE,                          "ERR_FILE_CANNOT_REWRITE",                      "Файл не может быть перезаписан.")
			/*5022*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_WRONG_DIRECTORYNAME,                     "ERR_FILE_WRONG_DIRECTORYNAME",                 "Неверное имя директории.")
			/*5023*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_DIRECTORY_NOT_EXIST,                     "ERR_FILE_DIRECTORY_NOT_EXIST",                 "Директория не существует.")
			/*5024*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOT_DIRECTORY,                           "ERR_FILE_NOT_DIRECTORY",                       "Указанный файл не является директорией.")
			/*5025*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_CANNOT_DELETE_DIRECTORY,                 "ERR_FILE_CANNOT_DELETE_DIRECTORY",             "Ошибка удаления директории.")
			/*5026*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_CANNOT_CLEAN_DIRECTORY,                  "ERR_FILE_CANNOT_CLEAN_DIRECTORY",              "Ошибка очистки директории.")
			/*5027*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_ARRAYRESIZE_ERROR,                       "ERR_FILE_ARRAYRESIZE_ERROR",                   "Ошибка изменения размера массива.")
			/*5028*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_STRINGRESIZE_ERROR,                      "ERR_FILE_STRINGRESIZE_ERROR",                  "Ошибка изменения размера строки.")
			/*5029*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_STRUCT_WITH_OBJECTS,                     "ERR_FILE_STRUCT_WITH_OBJECTS",                 "Структура содержит строки или динамические массивы.")
			/*5200*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_INVALID_ADDRESS,                   "ERR_WEBREQUEST_INVALID_ADDRESS",               "URL не прошел проверку.")
			/*5201*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_CONNECT_FAILED,                    "ERR_WEBREQUEST_CONNECT_FAILED",                "Не удалось подключиться к указанному URL.")
			/*5202*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_TIMEOUT,                           "ERR_WEBREQUEST_TIMEOUT",                       "Превышен таймаут получения данных.")
			/*5203*/	LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_REQUEST_FAILED,                    "ERR_WEBREQUEST_REQUEST_FAILED",                "Ошибка в результате выполнения HTTP запроса.")
    }

    // Return
    return(LIB_ERROR_LANGUAGE_FUNCTION(LIB_ERROR_LANG_TERM_ID_EN)(error_code));
};

#endif // LIB_ERRDESC_MQH_INCLUDED